Installation
============

Install the latest stable release using::

    pip install speclite

Alternatively, you can install the latest developer version from github::

    github clone https://github.com/dkirkby/speclite.git
    cd speclite
    python setup.py install
